AddressProperties class

Represents properties associated with a network address.

This class encapsulates information about an address, such as:

  • Whether it's local to the current node.
  • Whether it's static (should not be considered stale).
  • The last time it was seen (timestamp in milliseconds since epoch).

Constructors

AddressProperties({bool isLocal = false, bool isStatic = false, int? lastSeen})

Properties

hashCode int
The hash code for this object.
no setterinherited
isLocal bool
Indicates whether the address is local to the current node.
getter/setter pair
isNotLocal bool
no setter
isNotStatic bool
no setter
isStatic bool
Indicates whether the address is static and should not be considered stale
getter/setter pair
lastSeen int
The timestamp (in milliseconds since epoch) when the address was last seen
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

combine(AddressProperties other) → void
Combines the properties of this instance with another AddressProperties instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
updateLastSeen() → void
Updates the lastSeen timestamp to the current time.

Operators

operator ==(Object other) bool
The equality operator.
inherited