isLocal property
Indicates whether the address is local to the current node.
A local address belongs to the current node itself or is within its local network.
Implementation
bool isLocal;
Indicates whether the address is local to the current node.
A local address belongs to the current node itself or is within its local network.
bool isLocal;