Crypto class

Provides cryptographic functionalities for encrypting, decrypting, signing, and verifying data.

This class utilizes an isolate to perform cryptographic operations in a separate thread, ensuring that the main thread is not blocked. It handles key generation, sealing (encryption and signing), unsealing (decryption and verification), and signature verification.

Constructors

Crypto()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init([Uint8List? seed]) Future<InitResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seal(Uint8List datagram) Future<Uint8List>
toString() String
A string representation of this object.
inherited
unseal(Uint8List datagram) Future<Uint8List>
verify(Uint8List datagram) Future<Uint8List>

Operators

operator ==(Object other) bool
The equality operator.
inherited