ExceptionIsNotRunning class

Exception indicating that an operation was attempted on a router that is not currently running.

This exception is typically thrown when attempting to send or receive messages while the router is not active. It indicates that the router is in an invalid state for the requested operation.

Inheritance

Constructors

ExceptionIsNotRunning([Object? message = ''])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited