ExceptionUnknownRoute class

Exception indicating that an unknown route was encountered.

This exception is typically thrown when a message is received for a destination that is not registered with the router. It signifies that the router does not know how to deliver the message to the intended recipient.

Inheritance

Constructors

ExceptionUnknownRoute([Object? message = ''])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited