FullAddress class

Annotations
  • @immutable

Constructors

FullAddress({required InternetAddress address, required int port})
const

Properties

address InternetAddress
final
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type InternetAddressType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override