send abstract method

void send(
  1. Iterable<FullAddress> fullAddresses,
  2. Uint8List datagram
)

Sends a datagram to one or more addresses.

This method sends a datagram to the specified addresses using the underlying transport protocol. It is responsible for encoding the datagram and transmitting it over the network.

fullAddresses An iterable of FullAddress objects representing the destinations to send the datagram to. datagram The datagram data to be sent.

Implementation

void send(
  Iterable<FullAddress> fullAddresses,
  Uint8List datagram,
);