stop abstract method

void stop()

Stops the transport.

This method stops the transport and releases any resources that are being used. It should be called when the transport is no longer needed.

Implementation

void stop();