TransportUdp constructor
TransportUdp({
- required FullAddress bindAddress,
- Future<
void> onMessage(- Packet packet
- int ttl = 5,
Creates a new TransportUdp instance.
bindAddress The address to bind to for receiving incoming datagrams.
onMessage The callback function to invoke when a datagram is received.
ttl The time-to-live for outgoing datagrams, specifying the maximum
number of hops a datagram can traverse before being discarded.
Implementation
TransportUdp({
required super.bindAddress,
super.onMessage,
super.ttl,
});