stop method
Stops the transport.
This method closes the socket and releases any resources held by the transport.
Implementation
@override
void stop() {
_socket?.close();
_socket = null;
}
Stops the transport.
This method closes the socket and releases any resources held by the transport.
@override
void stop() {
_socket?.close();
_socket = null;
}