combine method
Combines the properties of this instance with another AddressProperties instance.
If the other instance has properties that are considered more relevant
(e.g., it's local, static, or has a more recent lastSeen timestamp),
those properties will be adopted by this instance.
This method is used to merge information about an address from different sources, prioritizing the most up-to-date and relevant properties.
Implementation
void combine(AddressProperties other) {
if (other.isLocal) isLocal = true;
if (other.isStatic) isStatic = true;
if (other.lastSeen > lastSeen) lastSeen = other.lastSeen;
}