isStatic property
Indicates whether the address is static and should not be considered stale
A static address is typically a manually configured address that is expected to be available long-term.
Implementation
bool isStatic;
Indicates whether the address is static and should not be considered stale
A static address is typically a manually configured address that is expected to be available long-term.
bool isStatic;