ExceptionBase class abstract
Base class for all exceptions thrown by this library.
Provides a consistent interface for handling exceptions, including an optional message for providing context. This abstract class is intended to be extended by specific exception types within the library.
- Implemented types
- Implementers
Constructors
- ExceptionBase([Object? message = ''])
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited