hasEmptyPayload static method
Checks if the signed datagram has an empty payload.
signedDatagram The signed datagram to check.
Returns true if the signed datagram has an empty payload,
false otherwise.
Implementation
static bool hasEmptyPayload(Uint8List signedDatagram) =>
signedDatagram.length == emptySignedMessageLength;