PeerId class
A Peer ID is a 64-byte value composed of two 32-byte keys:
- An encryption key, used to encrypt messages sent to the peer.
- A signing key, used to sign messages sent by the peer.
Constructors
- PeerId({required Uint8List value})
- PeerId.fromKeys({required Uint8List encryptionKey, required Uint8List signKey})
-
factory
Properties
- encPublicKey → Uint8List
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signPiblicKey → Uint8List
-
no setter
- value → Uint8List
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited