onMessage abstract method
Handles incoming messages.
packet The incoming Packet to be processed.
This method is called by the transports when a new message is received. It is responsible for routing the message to the appropriate destination or handling it locally.
Throws a StopProcessing exception if the message has been fully processed and further processing by child routers should be stopped.
Implementation
Future<Packet> onMessage(Packet packet);