start abstract method
Starts the transport.
This method initializes the transport and starts listening for incoming messages. It should be called before sending or receiving any data.
Implementation
Future<void> start();
Starts the transport.
This method initializes the transport and starts listening for incoming messages. It should be called before sending or receiving any data.
Future<void> start();